{% load i18n cms_tags %}

{% for plugin in instance.child_plugin_instances %}
    {% render_plugin plugin %}
{% empty %}
    {% trans "No audio file available." %}
{% endfor %}

{% comment %}
    # Available variables:
    {{ instance.template }}
    {{ instance.label }}
    {{ instance.attributes_str }}
{% endcomment %}
